@@ -1,37 +1,23 @@
 package Class::Value::Boolean;
-
-# $Id: Boolean.pm 11570 2006-06-06 13:29:50Z gr $
-
 use strict;
 use warnings;
-
-
-our $VERSION = '0.06';
-
-
+our $VERSION = '0.07';
 use base 'Class::Value::Enum';
+sub get_valid_values_list { (0, 1) }
 
-
-sub get_valid_values_list           { (0, 1) }
-
-sub get_value_normalization_hashref { {
-    J => 1,
-    j => 1,
-    Y => 1,
-    y => 1,
-    N => 0,
-    n => 0,
-} }
-
+sub get_value_normalization_hashref {
+    {   J => 1,
+        j => 1,
+        Y => 1,
+        y => 1,
+        N => 0,
+        n => 0,
+    };
+}
 
 # override to just use the value, no denormalization
-
 sub as_plaintext { $_[0]->value }
-
-
 1;
-
-
 __END__
 
 
@@ -141,7 +127,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Class-Value/>.
 
 =head1 AUTHORS
 
@@ -149,7 +135,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by the authors.
+Copyright 2004-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
