@@ -1,46 +1,36 @@
 package Class::Value::Enum;
-
-# $Id: Enum.pm 8411 2005-02-16 16:04:09Z gr $
-
 use strict;
 use warnings;
-
-
-our $VERSION = '0.06';
-
-
+our $VERSION = '0.07';
 use base 'Class::Value';
-
-
 sub get_valid_values_list           { () }
 sub get_value_normalization_hashref { {} }
 
-
 sub normalize_value {
     my ($self, $value) = @_;
     $self->normalize_enum_value($value);
 }
 
-
 sub normalize_enum_value {
     my ($self, $value) = @_;
     return unless defined $value;
-    return $value if grep { $_ eq $value } $self->get_valid_values_list;
-    $self->get_value_normalization_hashref->{lc $value};
+
+    my $ref = ref $self;
+    our %cache;
+    $cache{$ref} ||=
+        { map { $_ => 1 } @{ scalar $self->get_valid_values_list } };
+    return $value if $cache{$ref}{$value};
+    $self->get_value_normalization_hashref->{ lc $value };
+
     # automatically returns undef if it doesn't exist
 }
 
-
 sub as_plaintext {
-    my $self = shift;
+    my $self   = shift;
     my %lookup = reverse %{ $self->get_value_normalization_hashref };
-    $lookup{$self->value};
+    $lookup{ $self->value };
 }
-
-
 1;
-
-
 __END__
 
 
@@ -149,7 +139,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Class-Value/>.
 
 =head1 AUTHORS
 
@@ -157,7 +147,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by the authors.
+Copyright 2004-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
