@@ -1,21 +1,17 @@
 package Class::Value::Test;
-
-# $Id: Test.pm 13666 2007-11-07 07:53:28Z gr $
-
 use strict;
 use warnings;
 use Test::More;
-
-
-our $VERSION = '0.06';
-
-
+use Class::Value;
+our $VERSION = '0.07';
 use base 'Data::Semantic::Test';
 
-
+sub run {
+    my $self = shift;
+    $Class::Value::SkipChecks = 0;
+    $self->SUPER::run(@_);
+}
 1;
-
-
 __END__
 
 
@@ -97,7 +93,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Class-Value/>.
 
 =head1 AUTHORS
 
@@ -105,7 +101,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by the authors.
+Copyright 2004-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
